colour.plotting.diagrams Module — Colour 0.3.0 documentation

# colour.plotting.diagrams Module

## CIE Chromaticity Diagrams Plotting

Defines the CIE chromaticity diagrams plotting objects:

- `CIE_1931_chromaticity_diagram_plot()`
- `CIE_1960_UCS_chromaticity_diagram_plot()`
- `CIE_1976_UCS_chromaticity_diagram_plot()`

`colour.plotting.diagrams.` `CIE_1931_chromaticity_diagram_colours_plot`(*args, **kwargs)

  Plots the CIE 1931 Chromaticity Diagram colours.

  Parameters: | surface (numeric, optional) – Generated markers surface. spacing (numeric, optional) – Spacing between markers. cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1931_chromaticity_diagram_colours_plot()
      True

`colour.plotting.diagrams.` `CIE_1931_chromaticity_diagram_plot`(*args, **kwargs)

  Plots the CIE 1931 Chromaticity Diagram.

  Parameters: | cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1931_chromaticity_diagram_plot()
      True

`colour.plotting.diagrams.` `CIE_1960_UCS_chromaticity_diagram_colours_plot`(*args, **kwargs)

  Plots the CIE 1960 UCS Chromaticity Diagram colours.

  Parameters: | surface (numeric, optional) – Generated markers surface. spacing (numeric, optional) – Spacing between markers. cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1960_UCS_chromaticity_diagram_colours_plot()
      True

`colour.plotting.diagrams.` `CIE_1960_UCS_chromaticity_diagram_plot`(*args, **kwargs)

  Plots the CIE 1960 UCS Chromaticity Diagram.

  Parameters: | cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1960_UCS_chromaticity_diagram_plot()
      True

`colour.plotting.diagrams.` `CIE_1976_UCS_chromaticity_diagram_colours_plot`(*args, **kwargs)

  Plots the CIE 1976 UCS Chromaticity Diagram colours.

  Parameters: | surface (numeric, optional) – Generated markers surface. spacing (numeric, optional) – Spacing between markers. cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1976_UCS_chromaticity_diagram_colours_plot()
      True

`colour.plotting.diagrams.` `CIE_1976_UCS_chromaticity_diagram_plot`(*args, **kwargs)

  Plots the CIE 1976 UCS Chromaticity Diagram.

  Parameters: | cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> CIE_1976_UCS_chromaticity_diagram_plot()
      True